<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Rodyti failų tvarkyklėje</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Išvalyti žurnalą</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Atnaujinti</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Ar tikrai norite išvalyti žurnalą?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atšaukti</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Patvirtinti</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Viskas</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Šiuolaikinai</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dienos</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 savaitė</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mėnuo</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 mėnesiai</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksportuoti</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Viskas</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Kritinė</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Atmintis</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritinė</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Įspėjimas</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Pranešimas</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informacija</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Derinimo</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Prisijungimas</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Įjungimas</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Išjungimas</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Pamirštinė kritinė</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Atstovaukimas</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Tąsios identifikavimas</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>Skirtinis prieigos valdymas</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Pakankamumas prieigos valdymas</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Atminties</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Dokumento patikrinimas</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Kitas</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation>zip(*.zip</translation>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Eksportuojama...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atšaukti</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Eksportas sėkmingas</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Eksportavimas nepavyko</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>Eksportavimo katalogas neprieinamas. Pasirinkite kitą katalogą eksportavimui.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Eksportuoti failą</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Intervalus:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Rinkinys:  </translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Būsena:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipas:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Naudotojas:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Veiksmas:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Vartotojo vardas:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Įjungimo duomenys</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Išjungimo duomenys</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Prisijungimo duomenys</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Patikrinimo tipas:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>Programa:</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>ISKlaida:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Įspėjimas</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Derinimas</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informacija</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Kritinė situacija</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Atminties prieinamumas</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritinė</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Pranešimas</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Slaptažodis</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super kritinis</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Senzinė žurnalų failas</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Žurnalų žiūryklė</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Žurnalų peržiūra yra naudinga įrankis, skirtas peržiūrėti sisteminius žurnalus.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Nėra ieškomo rezultato</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ieškoti</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Ryšys</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Procesas</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Data ir laikas</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informacija</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Naudotojas</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Šaltinis</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Veiksmas</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Būsena</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Žuvimo tipas</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Vartotojo vardas</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Ryšys:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Procesas:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Data ir laikas:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informacija:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nulys</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Naudotojas:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Failo pavadinimas</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Pakeitimo laikas</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation>SIG</translation>
    </message>
    <message>
        <source>EXE</source>
        <translation>EXE</translation>
    </message>
    <message>
        <source>Core File</source>
        <translation>Koreliuotasis failas</translation>
    </message>
    <message>
        <source>User Name </source>
        <translation>Vartotojo vardas </translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>Iškraipymas</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data ir laikas</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Sistemos žurnalas</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Branduolio žurnalas</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Paleidimo žurnalas</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg žurnalas</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin žurnalas</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg žurnalas</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Aplikacijos žurnalas</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Įjungimo-išejimo įvykis</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf žurnalas</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Kitas žurnalas</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Nustatytas žurnalas</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>Kalibavimo žurnalas</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation>Kernel žurnalas</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>Nepavyko gauti informacijos apie klaidą, įdiekite systemd-coredump.</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>Nėra leidimų peržiūrėti jį</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>Sekurietinė lygis dangu: aukštas
 tik valdytojai gali peržiūrėti kalibavimo žurnalą</translation>
    </message>
    <message>
        <source>Audit log is not exist.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation>Eksportuoti žurnalus į nurodytą kelio</translation>
    </message>
    <message>
        <source>PATH</source>
        <translation>KELIAS</translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation>Eksportuoti žurnalus nurodytų tipų</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TIPO</translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation>Eksportuoti žurnalus nurodytų svyrantyjų programa</translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation>SVYRANTYJŲ PROGRAMOS VARDAS</translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation>Eksportuoti žurnalus nurodytu laikotarpiui</translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation>LAIKOTARPIS</translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation>Eksportuoti žurnalus nurodytu derinio lygute</translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation>LYGIS</translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation>BOOT STATUS</translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>Eksportuoti boot(no-klu) žurnalus nurodytu statusu</translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>Eksportuoti boot-shutdown-event arba kalibavimo žurnalus nurodytu event tipo</translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation>EVENT TYPE</translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation>Eksportuoti žurnalus pagal žymo paieškos rezultatus</translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation>ŽMĖPĖ</translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation>Ataskaita kernel informacijai.</translation>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation>Eksportuoti žurnalus pagal app submodel</translation>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation>PASKIRĖ</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Atstatymo intervalas</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 sek</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 min</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Neatstatyti</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Eksportuoti viską</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Atstatyti dabar</translation>
    </message>
</context>
</TS>